@@ -9,7 +9,7 @@ from onnx.reference.op_run import OpRun
 
 
 class Selu(OpRun):
-    def _run(self, x, alpha=None, gamma=None):  # type: ignore
+    def _run(self, x, alpha=None, gamma=None):
         return (
             (np.where(x > 0, x, np.exp(x) * alpha - alpha) * gamma).astype(x.dtype),
         )
